# -*- coding: utf-8 -*-
#
# Copyright 2022, Philippe Kueck <projects at unixadm dot org>
#
# This software may be freely redistributed under the terms of the GNU
# general public license version 2.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


import pymysql
import pymysql.converters
import pymysql.constants

class Dumper:

    def __init__(self, database, user, password, host="localhost"):
        _converter = pymysql.converters.conversions.copy()
        _converter[pymysql.constants.FIELD_TYPE.TIMESTAMP] = pymysql.converters.convert_time
        self._db = pymysql.connect(
            host=host, user=user, password=password, database=database,
            conv=_converter
        )
        self.database = database
        self.cursor = self._db.cursor(pymysql.cursors.DictCursor)

    def tables(self):
        self.cursor.execute(f"""
            select table_name from information_schema.tables where table_schema = %s
        """, self.database)
        tables = [t['table_name'] for t in self.cursor.fetchall()]
        return tables

    def table_schema(self, table):
        self.cursor.execute(f"show create table {table}")
        return self.cursor.fetchone()['Create Table']+";"

    def table_data(self, table):
        self.cursor.execute(f"select * from {table}")
        raw = self.cursor.fetchall()
        if len(raw) == 0: return None, None
        return list(raw[0].keys()), [list(x.values()) for x in raw]
